/******************************************************************************
 * The copyright in this software is being made available under the BSD        *
 * License, included below. This software may be subject to other third party  *
 * and contributor rights, including patent rights, and no such rights are     *
 * granted under this license.                                                 *
 *    <OWNER> = ISO                                                            *
 *    <ORGANIZATION> = ISO                                                     *
 *    <YEAR> = 2015                                                            *
 *    Copyright (c) 2012-2015, ISO                                             *
 *                                                                             *
 * All rights reserved.                                                        *
 * Redistribution and use in source and binary forms, with or without          *
 * modification, are permitted provided that the following conditions are met: *
 *       * Redistributions of source code must retain the above copyright      *
 *         notice,this list of conditions and the following disclaimer.        *
 *       * Redistributions in binary form must reproduce the above             *
 *         copyright notice, this list of conditions and the following         *
 *         disclaimer in the documentation and/or other materials provided     *
 *         with the distribution.                                              *
 *       * Neither the name of the <ORGANIZATION> nor the names of its         *
 *         contributors may be used to endorse or promote products derived     *
 *         from this software without specific prior written permission.       *
 *                                                                             *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" *
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE   *
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE  *
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   *
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         *
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF        *
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    *
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN     *
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)     *
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE  *
 * POSSIBILITY OF SUCH DAMAGE.                                                 *
 ******************************************************************************/

/** @file
 *  @brief Header file for the tonemapper library.
 *
 *  This file contains declarations of the functions, data structures, and enumerations for the tonemapper library.
 */

/** @defgroup tmoint Tonemapper Interface
 *  @brief Defines the API for the tonemapper library.
 *  @{
 */

#ifndef _TONEMAP_H
#define _TONEMAP_H

#include "jh_datatypes.h"

#ifdef __cplusplus
extern "C" {
#endif

/** @brief Defines the parameters that control the behavior of the tonemapper.
 *
 *  Parameters are specified depending on the type of tonemapper.
 */
typedef struct tmo_params_ts {
    float ec;                           /**< Manual adjust exposure compensation. */
} tmo_params_t;

/** @brief Tone maps an HDR image and returns an SDR image.
 *  @return 0 if the function does not succeed.
 */
int tonemap(
    const tmo_params_t *tmo_params,     /**< [in]     Tonemapper parameters. */
    jh_monitor_t *monitor,              /**< [in,out] Progress status of the function. The initial value of @c cancel must be 0. */
    const jh_image_t *hdri,             /**< [in]     HDR image. */
    jh_image_t *sdri,                   /**< [out]    Tone-mapped SDR image. The dimensions of the SDR image should be >= the
                                                      dimensions of the rendering rectangle. */
    jh_error_t* error                   /**< [in,out] User-allocated error-reporting structure that contains information about
                                                      the error. */
);

/** @brief Sets default tone-mapping parameters.
 *  @return 0 if the function does not succeed.
 */
int tonemap_set_default(
    tmo_params_t *params,               /**< [out]    User-allocated tonemapper parameters.  */
    jh_error_t *error                   /**< [in,out] User-allocated error-reporting structure that contains information about
                                                      the error. */
);

/**@}*/  /* end of defgroup tmoint */

#ifdef __cplusplus
}
#endif

#endif /* _TONEMAP_H */
